==> egov-common-1.0.6-sources.jar: com/gtis/plat/vo/PfFormDefineVo.java <==
package com.gtis.plat.vo;

import java.io.Serializable;
import java.util.Date;

public class PfFormDefineVo implements Serializable {

    String formDefinitionId;
    String formDefinitionName;
    String formDefinitionCode;
    Date createTime;
    String createVersion;
    String definitionXml;
    String definitionXlst;
    String selectCommand;
    String updateCommand;
    String insertCommand;
    byte[] formPrint;
    String definitionShell;

    public String getDefinitionShell() {
        return definitionShell;
    }

    public void setDefinitionShell(String definitionShell) {
        this.definitionShell = definitionShell;
    }

    public byte[] getFormPrint() {
        return formPrint;
    }

    public void setFormPrint(byte[] formPrint) {
        this.formPrint = formPrint;
    }

    public String getFormDefinitionId() {
        return formDefinitionId;
    }

    public void setFormDefinitionId(String formDefinitionId) {
        this.formDefinitionId = formDefinitionId;
    }

    public String getFormDefinitionName() {
        return formDefinitionName;
    }

    public void setFormDefinitionName(String formDefinitionName) {
        this.formDefinitionName = formDefinitionName;
    }

    public String getFormDefinitionCode() {
        return formDefinitionCode;
    }

    public void setFormDefinitionCode(String formDefinitionCode) {
        this.formDefinitionCode = formDefinitionCode;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public String getCreateVersion() {
        return createVersion;
    }

    public void setCreateVersion(String createVersion) {
        this.createVersion = createVersion;
    }

    public String getDefinitionXml() {
        return definitionXml;
    }

    public void setDefinitionXml(String definitionXml) {
        this.definitionXml = definitionXml;
    }

    public String getSelectCommand() {
        return selectCommand.toUpperCase();
    }

    public void setSelectCommand(String selectCommand) {
        this.selectCommand = selectCommand;
    }

    public String getUpdateCommand() {
        return updateCommand.toUpperCase();
    }

    public void setUpdateCommand(String updateCommand) {
        this.updateCommand = updateCommand;
    }

    public String getInsertCommand() {
        return insertCommand.toUpperCase();
    }

    public void setInsertCommand(String insertCommand) {
        this.insertCommand = insertCommand;
    }

    public String getDefinitionXlst() {
        return definitionXlst;
    }

    public void setDefinitionXlst(String definitionXlst) {
        this.definitionXlst = definitionXlst;
    }

}

==> egov-common-1.1.12.1-sources.jar: com/gtis/plat/vo/PfFormDefineVo.java <==
package com.gtis.plat.vo;

import org.apache.commons.lang3.StringUtils;

import java.io.Serializable;
import java.util.Date;

public class PfFormDefineVo implements Serializable {

    String formDefinitionId;
    String formDefinitionName;
    String formDefinitionCode;
    Date createTime;
    String createVersion;
    String definitionXml;
    String definitionXlst;
    String selectCommand;
    String updateCommand;
    String insertCommand;
    byte[] formPrint;
    String definitionShell;

    public String getDefinitionShell() {
        return definitionShell;
    }

    public void setDefinitionShell(String definitionShell) {
        this.definitionShell = definitionShell;
    }

    public byte[] getFormPrint() {
        return formPrint;
    }

    public void setFormPrint(byte[] formPrint) {
        this.formPrint = formPrint;
    }

    public String getFormDefinitionId() {
        return formDefinitionId;
    }

    public void setFormDefinitionId(String formDefinitionId) {
        this.formDefinitionId = formDefinitionId;
    }

    public String getFormDefinitionName() {
        return formDefinitionName;
    }

    public void setFormDefinitionName(String formDefinitionName) {
        this.formDefinitionName = formDefinitionName;
    }

    public String getFormDefinitionCode() {
        return formDefinitionCode;
    }

    public void setFormDefinitionCode(String formDefinitionCode) {
        this.formDefinitionCode = formDefinitionCode;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public String getCreateVersion() {
        return createVersion;
    }

    public void setCreateVersion(String createVersion) {
        this.createVersion = createVersion;
    }

    public String getDefinitionXml() {
        return definitionXml;
    }

    public void setDefinitionXml(String definitionXml) {
        this.definitionXml = definitionXml;
    }

    public String getSelectCommand() {
        if (StringUtils.isNotBlank(selectCommand))
            return selectCommand.toUpperCase();
        else
            return "select sysdate from dual";
    }

    public void setSelectCommand(String selectCommand) {
        this.selectCommand = selectCommand;
    }

    public String getUpdateCommand() {
        return updateCommand.toUpperCase();
    }

    public void setUpdateCommand(String updateCommand) {
        this.updateCommand = updateCommand;
    }

    public String getInsertCommand() {
        return insertCommand.toUpperCase();
    }

    public void setInsertCommand(String insertCommand) {
        this.insertCommand = insertCommand;
    }

    public String getDefinitionXlst() {
        return definitionXlst;
    }

    public void setDefinitionXlst(String definitionXlst) {
        this.definitionXlst = definitionXlst;
    }

}
